@@ -1,5 +1,5 @@
 package CAPDBICTest::CGIApp;
-our $VERSION = '0.092900';
+our $VERSION = '0.093010';
 
 
 use strict;
@@ -7,13 +7,12 @@ use warnings;
 
 use parent 'CGI::Application';
 
-use Readonly;
 use CGI::Application::Plugin::DBH (qw/dbh_config dbh/);
 use CAPDBICTest::Schema;
 use CGI::Application::Plugin::DBIx::Class ':all';
 
-Readonly our $DBFILE => 'test.db';
-Readonly our $CONNECT_STR => "dbi:SQLite:dbname=$DBFILE";
+our $DBFILE = 'test.db';
+our $CONNECT_STR = "dbi:SQLite:dbname=$DBFILE";
 
 sub cgiapp_init {
   my $self = shift;
