@@ -1,5 +1,5 @@
 package CAPDBICTest::Schema::Result::Stations;
-our $VERSION = '0.092900';
+our $VERSION = '0.093010';
 
 
 use parent 'DBIx::Class';
@@ -8,7 +8,12 @@ use warnings;
 
 __PACKAGE__->load_components('Core');
 __PACKAGE__->table('Station');
-__PACKAGE__->add_columns(qw/ id bill ted /);
+__PACKAGE__->add_columns(qw/bill ted /);
+__PACKAGE__->add_columns(
+   id => {
+      data_type => 'INTEGER',
+   }
+);
 __PACKAGE__->set_primary_key('id');
 
 1;
